package App::xlate;

use strict;
use warnings;

our $VERSION = "0.9909";

use Exporter 'import';
our @EXPORT_OK = qw($VERSION);

1;

__END__

=encoding utf-8

=head1 NAME

App::xlate - xlate script dummy module

=head1 SYNOPSIS

    use App::xlate;

=head1 DESCRIPTION

Document is included in C<xlate> script file.

=head1 LICENSE

Copyright ©︎ Kazumasa Utashiro.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

Kazumasa Utashiro

=cut

